%feature("docstring") OT::ExpertMixture
"Expert mixture defining a piece wise function according to a classifier.

Available constructors:
    ExpertMixture(*basis, classifier*)

Parameters
----------
basis : :class:`~openturns.Basis`
    A basis which is a collection of :class:`~openturns.Function`.
classifier : :class:`~openturns.Classifier`
    A classifier

See also
--------
Classifier, MixtureClassifier

Notes
-----
This implements an expert mixture which is a piece wise function :math:`f` 
defined by the collection of functions :math:`(f_i)_{i=1, \\\\ldots, N}` given in
*basis* and according to the classifier *classifier*:

.. math::

    f(\\\\vect{x}) &= f_1(\\\\vect{x}) \\\\hspace{1em} \\\\forall \\\\vect{x} \\\\in \\\\text{Classe} 1 \\\\\\\\
                &= f_k(\\\\vect{x}) \\\\hspace{1em} \\\\forall \\\\vect{x} \\\\in \\\\text{Classe} k \\\\\\\\
                &= f_N(\\\\vect{x}) \\\\hspace{1em} \\\\forall \\\\vect{x} \\\\in \\\\text{Classe} N

where the :math:`N` classes are defined by the classifier.

Usage:

- ExpertMixture(*input*)
 
where *input* is a sequence of float or a 2-d sequence of float. It represents a
point or a set of points to evaluate using the expert mixture.

The input vector *input* is assigned to a particular class according to the
rules defined by *classifier* and the associated marginal function :math:`f_i`
is used to evaluate :math:`f(input)`.
"

// ---------------------------------------------------------------------

%feature("docstring") OT::ExpertMixture::getExperts
"Accessor the basis.

Returns
-------
basis : :class:`~openturns.Basis`
    The collection of functions :math:`(f_i)_{i=1, \\\\ldots, N}`."

// ---------------------------------------------------------------------

%feature("docstring") OT::ExpertMixture::setExperts
"Accessor the basis.

Parameters
----------
basis : :class:`~openturns.Basis`
    The collection of functions :math:`(f_i)_{i=1, \\\\ldots, N}`."

// ---------------------------------------------------------------------

%feature("docstring") OT::ExpertMixture::getClassifier
"Accessor the classifier.

Returns
-------
classifier : :class:`~openturns.Classifier`
    The classifier."

// ---------------------------------------------------------------------

%feature("docstring") OT::ExpertMixture::setClassifier
"Accessor the classifier.

Parameters
----------
classifier : :class:`~openturns.Classifier`
    The classifier."