%feature("docstring") OT::GramSchmidtAlgorithm
"GramSchmidt algorithm used to build the orthonormal basis.

The algorithm builds the basis with respect to a specific distribution.

Available constructors:
    GramSchmidtAlgorithm(*measure*)

    GramSchmidtAlgorithm(*measure, referenceFamily*)

Parameters
----------
measure : :class:`~openturns.Distribution`
    A measure for which the orthonormal polynomial basis is built. 
referenceFamily : :class:`~openturns.OrthogonalUniVariatePolynomialFamily`
    A polynomial family from which the algorithm starts to build the orthonornal
    polynomial family. When not specified, the *referenceFamily* is the
    canonical one: :math:`\\\\{ 1, x, x^2, \\\\ldots\\\\}`.

See also
--------
OrthonormalizationAlgorithm, ChebychevAlgorithm

Notes
-----
It implements the Gram-Schmidt algorithm that builds the orthonormalized
polynomial family with respect to the distribution *measure*, where the initial
polynomial family is the one specified in *referenceFamily*. "

// ---------------------------------------------------------------------

%feature("docstring") OT::GramSchmidtAlgorithm::getReferenceFamily
"Accessor to the reference family.

Returns
-------
family : :class:`~openturns.OrthogonalUniVariatePolynomialFamily`
    The polynomial family from which the orthonormal polynomial family is built."

// ---------------------------------------------------------------------

%feature("docstring") OT::GramSchmidtAlgorithm::setReferenceFamily
"Accessor to the reference family.

Parameters
----------
family : :class:`~openturns.OrthogonalUniVariatePolynomialFamily`
    The polynomial family from which the orthonormal polynomial family is built."
