%feature("docstring") OT::WeibullMuSigma
"Weibull distribution parameters.

Available constructors:
    WeibullMuSigma(*mu=1.0, sigma=1.0, gamma=0.*)

Parameters
----------
mu : float
    Mean.
sigma : float
    Standard deviation :math:`\\\\sigma > 0`.
gamma : float, optional
    Shift parameter :math:`\\\\gamma > \\\\mu`.

Notes
-----
The native parameters :math:`\\\\alpha` and :math:`\\\\beta` are searched such as:

.. math::

    \\\\alpha &= \\\\frac{\\\\mu - \\\\gamma}{\\\\Gamma(1+\\\\frac{1}{\\\\beta})} \\\\\\\\
    \\\\sigma^2 &= \\\\alpha^2 \\\\Gamma\\\\left(1 + \\\\frac{2}{\\\\beta}\\\\right) -
                   \\\\Gamma^2 \\\\left(1 + \\\\frac{1}{\\\\beta}\\\\right)

See also
--------
Weibull

Examples
--------
Create the parameters of the Weibull distribution:

>>> import openturns as ot
>>> parameters = ot.WeibullMuSigma(1.3, 1.23, -0.5)

Convert parameters into the native parameters:

>>> print(parameters.evaluate())
[1.99222,1.48961,-0.5]

The gradient of the transformation of the native parameters into the new
parameters:

>>> print(parameters.gradient())
[[  1.25624   0.897176  0        ]
 [ -0.218715 -1.31294   0        ]
 [ -1.25624  -0.897176  1        ]]"
